Skip to contents

A teaching dataset used in *Reproducible Research Using R*. This dataset is primarily used for examples involving data visualization and linear regression.

Usage

pizza_prices

Format

A data frame with 156 rows and 3 variables:

Week

Week number of observation.

Total Volume

Total number of pizzas sold in that week.

Total Price

Total revenue generated from pizza sales in that week.

Created for the textbook *Reproducible Research Using R*.