`chapter_script()` is deprecated. Use [chapter_materials()] instead to copy the complete set of materials associated with a textbook chapter.
This function is retained for backward compatibility with existing code.
Usage
chapter_script(
chapter,
type = c("full", "helper"),
dest,
run = FALSE,
overwrite = FALSE,
open = FALSE
)Examples
if (FALSE) { # \dontrun{
tmp <- tempdir()
chapter_script(3, "helper", dest = tmp, overwrite = TRUE)
} # }