Learn R Programming

reproresearchR (version 0.1.1)

pizza_prices: Pizza prices dataset

Description

A teaching dataset used in *Reproducible Research Using R*. This dataset is primarily used for examples involving data visualization and linear regression.

Usage

pizza_prices

Arguments

Format

A data frame with 156 rows and 3 variables:

Week

Week number of observation.

Total Volume

Total number of pizzas sold in that week.

Total Price

Total revenue generated from pizza sales in that week.